export declare const allowedMethods: string[];
export declare const bodyTypes: string[];
export declare const dataFilters: string[];
export declare const devices: string[];
export declare type TAdapter = (options: {
    method: string;
    url: string;
    headers: {
        [k: string]: string;
    };
    body: {
        [k: string]: any;
    };
}) => Promise<TScrapeResult[]>;
export declare type TGlobalOptions = {
    adapter?: TAdapter;
};
export declare type TBasicRequest = {
    url: string;
    method?: HttpMethod;
    cookies?: string;
    device?: typeof devices[number];
};
export declare type HttpMethod = typeof allowedMethods[number];
export declare type TRequestWithBody = TBasicRequest & {
    body: {
        [key: string]: any;
    };
    bodyType: typeof bodyTypes[number];
};
export declare type TRequest = TBasicRequest | TRequestWithBody;
export declare type TRequestWithExtractors = TRequest & {
    extract?: TExtractor;
    withBody?: boolean;
    withHeaders?: boolean;
};
export declare type TExtractor = TItemsExtractor | TValueExtractor | ValueExtractor | TItemsIterator;
export declare type TSelector = "this" | string;
export declare type TAttribute = "text" | "html" | string;
export declare type TFilter = typeof dataFilters[number];
export declare type TValueExtractor = {
    select: TSelector;
    attr?: TAttribute;
    required?: boolean;
    filters?: TFilter[];
};
export declare type TItemsIterator = {
    $foreach?: string;
    items: {
        [name: string]: TExtractor;
    };
};
export declare type TItemsExtractor = {
    [name: string]: TExtractor;
};
export declare class ValueExtractor {
    options: TValueExtractor;
    constructor(select: TSelector);
    attr(attribute: TAttribute): this;
    each(values: {
        [name: string]: TExtractor;
    }): TItemsIterator;
    filter(filterName: TFilter): this;
    optional(isOptional?: boolean): this;
}
export declare type TExtractedPrice = {
    amount: number;
    currency: string;
};
export declare type TScrapeResult<TData extends any = any> = {
    url: string;
    status: number;
    headers?: {
        [key: string]: string;
    };
    body?: string;
    data?: TData;
    time: number;
    bandwidth: number;
};
